@@ -38,6 +38,7 @@
 #include <analitza/value.h>
 
 #include <QVBoxLayout>
+#include <QActionGroup>
 #include <QHeaderView>
 #include <QDockWidget>
 #include <QTableView>
@@ -66,14 +67,14 @@ class Add2DOption : public InlineOptions
         : m_kalgebra(c)
         {}
         
-        QString id() const Q_DECL_OVERRIDE { return QStringLiteral("add2d"); }
-        bool matchesExpression(const Analitza::Expression& exp) const Q_DECL_OVERRIDE {
+        QString id() const override { return QStringLiteral("add2d"); }
+        bool matchesExpression(const Analitza::Expression& exp) const override {
             return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D).canDraw();
         }
 
-        QString caption() const Q_DECL_OVERRIDE { return i18n("Plot 2D"); }
+        QString caption() const override { return i18n("Plot 2D"); }
 
-        void triggerOption(const Analitza::Expression& exp) Q_DECL_OVERRIDE { m_kalgebra->add2D(exp); }
+        void triggerOption(const Analitza::Expression& exp) override { m_kalgebra->add2D(exp); }
     
     private:
         KAlgebra* m_kalgebra;
@@ -86,15 +87,15 @@ class Add3DOption : public InlineOptions
         : m_kalgebra(c)
         {}
         
-        QString id() const Q_DECL_OVERRIDE { return QStringLiteral("add3d"); }
-        bool matchesExpression(const Analitza::Expression& exp) const Q_DECL_OVERRIDE
+        QString id() const override { return QStringLiteral("add3d"); }
+        bool matchesExpression(const Analitza::Expression& exp) const override
         {
             return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D).canDraw();
         }
 
-        QString caption() const Q_DECL_OVERRIDE { return i18n("Plot 3D"); }
+        QString caption() const override { return i18n("Plot 3D"); }
 
-        void triggerOption(const Analitza::Expression& exp) Q_DECL_OVERRIDE { m_kalgebra->add3D(exp); }
+        void triggerOption(const Analitza::Expression& exp) override { m_kalgebra->add3D(exp); }
     
     private:
         KAlgebra* m_kalgebra;
@@ -170,13 +171,13 @@ KAlgebra::KAlgebra(QWidget *parent)
     c_menu = menuBar()->addMenu(i18n("C&alculator"));
     
     c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("@item:inmenu", "&Load Script..."),
-                        this, SLOT(loadScript()), Qt::CTRL+Qt::Key_L);
+                        this, SLOT(loadScript()), Qt::CTRL | Qt::Key_L);
     c_recentScripts=new KRecentFilesAction(QIcon::fromTheme(QStringLiteral("document-open-recent")), i18n("Recent Scripts"), this);
     connect(c_recentScripts, SIGNAL(urlSelected(QUrl)), this, SLOT(loadScript(QUrl)));
     c_menu->addAction(c_recentScripts);
     
     c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Save Script..."),
-                        this, &KAlgebra::saveScript, Qt::CTRL+Qt::Key_G);
+                        this, &KAlgebra::saveScript, Qt::CTRL | Qt::Key_G);
     c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Export Log..."),
                         this, &KAlgebra::saveLog, QKeySequence::Save);
     c_menu->addSeparator();
